@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import argparse
 import sys
-from icecream import ic
+from icecream import ic # type: ignore
 
 from tko.cmds.cmd_task import CmdTask
 from tko.cmds.cmd_rep import CmdRep
@@ -28,6 +28,7 @@ from tko.util.raw_terminal import RawTerminal
 from tko.util.symbols import symbols
 from tko.settings.check_version import CheckVersion
 from tko.settings.rep_starter import RepStarter
+from tko.settings.rep_source_actions import RepSourceActions
 
 from tko.__init__ import __version__
 
@@ -112,11 +113,12 @@ class Main:
     @staticmethod
     def open(args: argparse.Namespace):
         settings = Settings()
+        update: bool = args.update
         folder = args.folder
         rec_folder = RepPaths.rec_search_for_repo(folder)
         if rec_folder != "":
             folder = rec_folder
-        action = CmdOpen(settings).load_folder(folder)
+        action = CmdOpen(settings, update).load_folder(folder)
         if not CheckVersion().is_updated():
             action.set_need_update()
         action.execute()
@@ -138,13 +140,44 @@ class Main:
 
     @staticmethod
     def init(args: argparse.Namespace):
-        remote: str | None = args.remote
-        source: str | None = args.source
         folder: str | None = args.folder
         language: str | None = args.language
-        database: str | None = args.database
-        filters: list[str] | None = args.filter
-        RepStarter(remote=remote, source=source, folder=folder, language=language, database=database, filters=filters)
+        rep_starter = RepStarter(folder=folder, language=language)
+        ok: bool = rep_starter.execute()
+        remote: str | None = args.remote
+        enable: list[str] | None = args.enable
+        if ok and remote is not None:
+            rep_actions = RepSourceActions(folder)
+            rep_actions.add_source(alias=remote, remote=remote, link=None, filters=enable)
+        rep_starter.print_end_msg()
+
+    @staticmethod
+    def source_list(args: argparse.Namespace):
+        folder: str | None = args.folder
+        rep_actions = RepSourceActions(folder)
+        rep_actions.list_sources()
+
+    @staticmethod
+    def source_add(args: argparse.Namespace):
+        remote: str | None = args.remote
+        link: str | None = args.link 
+        folder: str | None = args.folder
+        alias: str = args.alias
+        enable: list[str] | None = args.enable
+        try:
+            rep_actions = RepSourceActions(folder)
+            rep_actions.add_source(remote=remote, alias=alias, link=link, filters=enable)
+            rep_actions.print_end_msg()
+        except ValueError as e:
+            print(f"Erro ao adicionar fonte: {e}")
+
+    @staticmethod
+    def source_enable(args: argparse.Namespace):
+        alias: str = args.alias
+        folder: str | None = args.folder
+        enable: list[str] | None = args.enable
+        rep_actions = RepSourceActions(folder)
+        rep_actions.source_enable(alias=alias, filters=enable)
 
     @staticmethod
     def config(args: argparse.Namespace):
@@ -324,6 +357,7 @@ class Parser:
     def add_parser_rep_actions(self):
         parser_open = self.subparsers.add_parser('open', help='Open a folder with a repository.')
         parser_open.add_argument('folder', type=str, nargs='?', default='.', help='Repository folder.')
+        parser_open.add_argument('--update', '-u', action='store_true', help='Force update.')
         parser_open.set_defaults(func=Main.open)
 
         parser_down = self.subparsers.add_parser('task', help='Task subcommands.')
@@ -333,20 +367,39 @@ class Parser:
         exclusive_group.add_argument('--down', action='store_true', help="Download task from repository.")
         # exclusive_group.add_argument('--self', action='store_true', help="Self evaluate task in repository.") # TODO
         exclusive_group.add_argument('--graph', nargs=2, type=int, metavar=('WIDTH', 'HEIGHT'), help="Show task graph.")
-
         parser_down.set_defaults(func=Main.task)
 
-        parser_init = self.subparsers.add_parser('init', help='Initialize a repository in a folder.')
-        source = parser_init.add_mutually_exclusive_group()
-        source.add_argument('--remote', '-r', type=str, help='Remote source [fup|ed|poo].')
-        source.add_argument('--source', '-s', type=str, help='HTTP url or local file.')
+        parser_init = self.subparsers.add_parser('init', help='Initialize a empty repository in a folder.')
         parser_init.add_argument('--folder', '-f', type=str, help='Local directory.')
         parser_init.add_argument('--language', '-l', type=str, help='Draft language for the repository.')
-        parser_init.add_argument('--database', '-d', type=str, help='Define database folder.')
-        parser_init.add_argument('--filter', type=str, nargs='+', help='Only accept quests this patterns.')
+        parser_init.add_argument('--remote', '-r', type=str, help='Init with remote source [fup|ed|poo].')
+        parser_init.add_argument('--enable', '-e', type=str, nargs='*', help='Only show enabled items')
         parser_init.set_defaults(func=Main.init)
 
 
+        parser_source = self.subparsers.add_parser('source', help='Adds a source to a repository folder.')
+        sub_source = parser_source.add_subparsers(title='source commands', help='help for subcommand.')
+        # create subcommands inside source
+        source_add = sub_source.add_parser("add", help="Add a new task source")
+        source_add.add_argument('--folder', '-f', type=str, help='Repository folder.')
+        source_add.add_argument('alias', type=str, help='Alias for the remote.')
+        source_from = source_add.add_mutually_exclusive_group()
+        source_from.add_argument('--link', '-l', type=str, help='HTTP url or local file.')
+        source_from.add_argument('--remote', '-r', type=str, help='Remote source [fup|ed|poo].')
+        source_add.add_argument('--enable', '-e', type=str, nargs='*', help='Only show enabled items')
+        source_add.set_defaults(func=Main.source_add)
+
+        source_list = sub_source.add_parser("list", help="List sources")
+        source_list.add_argument('--folder', '-f', type=str, help='Repository folder.')
+        source_list.set_defaults(func=Main.source_list)
+
+        source_enable = sub_source.add_parser("enable", help="Enable filters on a source")
+        source_enable.add_argument('--folder', '-f', type=str, help='Repository folder.')
+        source_enable.add_argument('alias', type=str, help='Alias for the remote.')
+        source_enable.add_argument('enable', type=str, nargs='*', help='Only show enabled items')
+        source_enable.set_defaults(func=Main.source_enable)
+
+
 def execute(parser: argparse.ArgumentParser, args: argparse.Namespace) -> int:
     settings = Settings()
     if args.w is not None:
