@@ -70,14 +70,14 @@ class Gui:
             quest: Quest = obj
             if Flags.quests.get_value() != "2" and not quest.is_reachable():
                 output = TaskAction.BLOQUEIO
-            elif quest.key in self.tree.expanded:
+            elif quest.get_db_key() in self.tree.expanded:
                 output = TaskAction.CONTRAIR
             else:
                 output = TaskAction.EXPANDIR
             return "Y", output
         elif isinstance(obj, Cluster):
             cluster: Cluster = obj
-            if cluster.key in self.tree.expanded:
+            if cluster.get_db_key() in self.tree.expanded:
                 output = TaskAction.CONTRAIR
             else:
                 output = TaskAction.EXPANDIR
@@ -150,7 +150,7 @@ class Gui:
         dirname: str = self.rep.paths.get_rep_dir()
         dirname = os.path.basename(dirname).upper()
         text.add(self.style.border(alias_color, dirname))
-        text.add(self.style.border("G", self.rep.get_lang().upper()))
+        text.add(self.style.border("G", self.rep.data.lang.upper()))
         if self.need_update:
             text = Text().addf("r", " TKO DESATUALIZADO!").addf("y"," Atualize com: ").addf("g", "pipx upgrade tko ")
         text = self.center_header_footer(text, frame)
@@ -349,26 +349,6 @@ class Gui:
         _help.put_sentence(Text() + Text.r_token("g", "             tko config --editor <comando>"))
 
 
-    # def build_xp_bar(self) -> tuple[str, float]:
-    #     xp = XP(self.game)
-    #     available = xp.get_xp_total_available()
-    #     if 0 < available == xp.get_xp_total_obtained():
-    #         text = "Você atingiu o máximo de xp!"
-    #         percent = 100.0
-    #     else:
-    #         # lang = self.rep.get_lang().upper()
-    #         level = xp.get_level()
-    #         percent = float(xp.get_xp_level_current()) / float(xp.get_xp_level_needed())
-    #         if Flags.percent:
-    #             xpobt = int(100 * xp.get_xp_level_current() / xp.get_xp_level_needed())
-    #             text = "Level:{} XP:{}%".format(level, xpobt)
-    #         else:
-    #             xpobt1 = round(xp.get_xp_level_current())
-    #             xpobt2 = round(xp.get_xp_level_needed())
-    #             text = "Level:{} XP:{}/{}".format(level, xpobt1, xpobt2)
-
-    #     return text, percent
-
     def get_task_graph(self, task_key: str, width: int, height: int) -> tuple[bool, list[Text]]:
         tg = TaskGraph(self.settings, self.rep, task_key, width, height)
         if len(tg.collected_rate) == 1:
@@ -406,7 +386,7 @@ class Gui:
             if height < 3:
                 height = 3
             if isinstance(selected, Task):
-                made, list_data = self.get_task_graph(selected.key, width, height)
+                made, list_data = self.get_task_graph(selected.get_db_key(), width, height)
             elif isinstance(selected, Cluster) or isinstance(selected, Quest):
                 made, list_data = self.get_daily_graph(width, height)
         if not made:
