@@ -1,28 +1,26 @@
-from typing import List, Optional, Tuple
 import math
 import os
 
 from tko.util.identifier import Identifier
-
-from tko.util.consts import IdentifierType
+from tko.enums.identifier_type import IdentifierType
 from tko.run.unit import Unit
 from tko.util.param import Param
 from tko.run.loader import Loader
 from tko.run.solver_builder import SolverBuilder
-
-from tko.down.drafts import Drafts
 from tko.util.text import Text
 from tko.util.symbols import symbols
 from tko.util.label_factory import LabelFactory
-from tko.settings.repository import available_languages
+from tko.down.drafts import Drafts
+from tko.settings.languages import available_languages
+
 class Wdir:
     def __init__(self):
         self.__autoload = False
         self.__autoload_folder = ""
-        self.__solver: Optional[SolverBuilder] = None
-        self.__source_list: List[str] = []
-        self.__pack_list: List[List[Unit]] = []
-        self.__unit_list: List[Unit] = []
+        self.__solver: None | SolverBuilder = None
+        self.__source_list: list[str] = []
+        self.__pack_list: list[list[Unit]] = []
+        self.__unit_list: list[Unit] = []
         self.__curses = False
         self.__lang = ""
 
@@ -37,13 +35,13 @@ class Wdir:
             raise Warning("fail: Não foi encontrado arquivo de código")
         return self.__solver
     
-    def get_unit_list(self) -> List[Unit]:
+    def get_unit_list(self) -> list[Unit]:
         return self.__unit_list
 
     def get_unit(self, index: int) -> Unit:
         return self.__unit_list[index]
     
-    def get_source_list(self) -> List[str]:
+    def get_source_list(self) -> list[str]:
         return self.__source_list
 
     def set_curses(self, value: bool):
@@ -63,12 +61,12 @@ class Wdir:
     def get_autoload_folder(self) -> str:
         return self.__autoload_folder
 
-    def set_solver(self, solver_list: List[str]):
+    def set_solver(self, solver_list: list[str]):
         if len(solver_list) > 0:
             self.__solver = SolverBuilder(solver_list)
         return self
 
-    def set_sources(self, source_list: List[str]):
+    def set_sources(self, source_list: list[str]):
         self.__source_list = source_list
         return self
 
@@ -83,9 +81,10 @@ class Wdir:
             source_list = [target for target in files if target.endswith(".md")]
         source_list = [os.path.join(folder, x) for x in source_list]
         
-        solver_list: list[str] = []
         if self.__lang != "":
-            solver_list = Drafts.load_drafs(folder, self.__lang)
+            solver_list = Drafts.load_drafts_only(folder, self.__lang)
+        else:
+            solver_list = Drafts.load_drafts_only(folder, "", extra=available_languages)
         solver_list = sorted(solver_list)
 
         # if not self.__curses:
@@ -97,7 +96,7 @@ class Wdir:
         self.__autoload = True
         return self
 
-    def set_target_list(self, target_list: List[str]):
+    def set_target_list(self, target_list: list[str]):
         target_list = [os.path.normpath(t) for t in target_list]
         if len(target_list) == 0:
             target_list.append(".")
@@ -129,7 +128,7 @@ class Wdir:
                 pass
         if loading_failures > 0 and loading_failures == len(self.__source_list):
             raise FileNotFoundError("failure: nenhum arquivo de teste encontrado")
-        self.__unit_list = sum(self.__pack_list, [])
+        self.__unit_list = sum(self.__pack_list, []) # type: ignore
         self.__number_and_mark_duplicated()
         self.__calculate_grade()
         self.__pad()
@@ -138,7 +137,7 @@ class Wdir:
     def calc_grade(self) -> int:
         grade = 100
         for case in self.__unit_list:
-            if not case.repeated and (case.received is None or case.expected != case.received):
+            if not case.repeated and (case.get_received() is None or case.get_expected() != case.get_received()):
                 grade -= case.grade_reduction
         return max(0, grade)
 
@@ -174,7 +173,7 @@ class Wdir:
 
     # number the cases and mark the repeated
     def __number_and_mark_duplicated(self):
-        new_list: List[Unit] = []
+        new_list: list[Unit] = []
         index = 0
         for unit in self.__unit_list:
             unit.index = index
@@ -200,11 +199,11 @@ class Wdir:
                 unit.case = LabelFactory().label(unit.case).index(number).generate()
                 number += 1
 
-    def unit_list_resume(self) -> List[Text]:
+    def unit_list_resume(self) -> list[Text]:
         return [unit.str() for unit in self.__unit_list]
 
-    def sources_names(self) -> List[Tuple[str, int]]:
-        out: List[Tuple[str, int]] = []
+    def sources_names(self) -> list[tuple[str, int]]:
+        out: list[tuple[str, int]] = []
         if len(self.__pack_list) == 0:
             out.append((symbols.failure.text, 0))
         for i in range(len(self.__pack_list)):
@@ -212,18 +211,22 @@ class Wdir:
             out.append((nome, len(self.__pack_list[i])))
         return out
 
-    def solvers_names(self) -> List[str]:
-        path_list = [] if self.__solver is None else self.__solver.path_list
+    def solvers_names(self) -> list[str]:
+        path_list = [] if self.__solver is None else self.__solver.args_list
         if self.__solver is not None and len(path_list) == 0:  # free_cmd
             out = ["free cmd"]
         else:
             out = [os.path.basename(path) for path in path_list]
         return out
 
-    def resume(self) -> Text:
+    def resume_splitted(self) -> Text:
         sources = ["{}({})".format(name, str(count).rjust(2, "0")) for name, count in self.sources_names()]
         __sources = Text().add("Testes:").add("[").addf("y", ", ".join(sources)).add("]")
-
         __solvers = Text().add("Códigos:").add("[").addf("g", ", ".join(self.solvers_names())).add("]")
-
         return Text().add(__solvers).add(" ").add(__sources)
+
+    def resume_join(self) -> Text:
+        sources = ["{}({})".format(name, str(count).rjust(2, "0")) for name, count in self.sources_names()]
+        __sources = Text().addf("y", ", ".join(sources))
+        __solvers = Text().addf("g", ", ".join(self.solvers_names()))
+        return Text().add(__solvers).add(", ").add(__sources)
\ No newline at end of file
